package
Version:
v0.0.0-...-d5719a6
Opens a new window with list of versions in this module.
Published: Jan 29, 2018
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type FileInfo struct {
IsFile bool `json:"leaf"`
FullPath string `json:"path"`
Label string `json:"label"`
Subs []*FileInfo `json:"children"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.